import playfab.PlayFabErrors as PlayFabErrors
import playfab.PlayFabHTTP as PlayFabHTTP
import playfab.PlayFabSettings as PlayFabSettings

""" APIs for managing title configurations, uploaded Game Server code executables, and user data """


def AbortTaskInstance(request, callback, customData = None, extraHeaders = None):
    """
    Abort an ongoing task instance.
    https://api.playfab.com/documentation/admin/method/AbortTaskInstance
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/AbortTaskInstance", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def AddNews(request, callback, customData = None, extraHeaders = None):
    """
    Adds a new news item to the title's news feed
    https://api.playfab.com/documentation/admin/method/AddNews
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/AddNews", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def AddPlayerTag(request, callback, customData = None, extraHeaders = None):
    """
    Adds a given tag to a player profile. The tag's namespace is automatically generated based on the source of the tag.
    https://api.playfab.com/documentation/admin/method/AddPlayerTag
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/AddPlayerTag", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def AddServerBuild(request, callback, customData = None, extraHeaders = None):
    """
    Adds the game server executable specified (previously uploaded - see GetServerBuildUploadUrl) to the set of those a
    client is permitted to request in a call to StartGame
    https://api.playfab.com/documentation/admin/method/AddServerBuild
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/AddServerBuild", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def AddUserVirtualCurrency(request, callback, customData = None, extraHeaders = None):
    """
    Increments the specified virtual currency by the stated amount
    https://api.playfab.com/documentation/admin/method/AddUserVirtualCurrency
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/AddUserVirtualCurrency", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def AddVirtualCurrencyTypes(request, callback, customData = None, extraHeaders = None):
    """
    Adds one or more virtual currencies to the set defined for the title. Virtual Currencies have a maximum value of
    2,147,483,647 when granted to a player. Any value over that will be discarded.
    https://api.playfab.com/documentation/admin/method/AddVirtualCurrencyTypes
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/AddVirtualCurrencyTypes", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def BanUsers(request, callback, customData = None, extraHeaders = None):
    """
    Bans users by PlayFab ID with optional IP address, or MAC address for the provided game.
    https://api.playfab.com/documentation/admin/method/BanUsers
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/BanUsers", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def CheckLimitedEditionItemAvailability(request, callback, customData = None, extraHeaders = None):
    """
    Checks the global count for the limited edition item.
    https://api.playfab.com/documentation/admin/method/CheckLimitedEditionItemAvailability
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/CheckLimitedEditionItemAvailability", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def CreateActionsOnPlayersInSegmentTask(request, callback, customData = None, extraHeaders = None):
    """
    Create an ActionsOnPlayersInSegment task, which iterates through all players in a segment to execute action.
    https://api.playfab.com/documentation/admin/method/CreateActionsOnPlayersInSegmentTask
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/CreateActionsOnPlayersInSegmentTask", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def CreateCloudScriptTask(request, callback, customData = None, extraHeaders = None):
    """
    Create a CloudScript task, which can run a CloudScript on a schedule.
    https://api.playfab.com/documentation/admin/method/CreateCloudScriptTask
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/CreateCloudScriptTask", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def CreatePlayerSharedSecret(request, callback, customData = None, extraHeaders = None):
    """
    Creates a new Player Shared Secret Key. It may take up to 5 minutes for this key to become generally available after
    this API returns.
    https://api.playfab.com/documentation/admin/method/CreatePlayerSharedSecret
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/CreatePlayerSharedSecret", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def CreatePlayerStatisticDefinition(request, callback, customData = None, extraHeaders = None):
    """
    Adds a new player statistic configuration to the title, optionally allowing the developer to specify a reset interval
    and an aggregation method.
    https://api.playfab.com/documentation/admin/method/CreatePlayerStatisticDefinition
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/CreatePlayerStatisticDefinition", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeleteContent(request, callback, customData = None, extraHeaders = None):
    """
    Delete a content file from the title. When deleting a file that does not exist, it returns success.
    https://api.playfab.com/documentation/admin/method/DeleteContent
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeleteContent", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeleteMasterPlayerAccount(request, callback, customData = None, extraHeaders = None):
    """
    Removes a master player account entirely from all titles and deletes all associated data
    https://api.playfab.com/documentation/admin/method/DeleteMasterPlayerAccount
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeleteMasterPlayerAccount", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeletePlayer(request, callback, customData = None, extraHeaders = None):
    """
    Removes a user's player account from a title and deletes all associated data
    https://api.playfab.com/documentation/admin/method/DeletePlayer
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeletePlayer", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeletePlayerSharedSecret(request, callback, customData = None, extraHeaders = None):
    """
    Deletes an existing Player Shared Secret Key. It may take up to 5 minutes for this delete to be reflected after this API
    returns.
    https://api.playfab.com/documentation/admin/method/DeletePlayerSharedSecret
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeletePlayerSharedSecret", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeleteStore(request, callback, customData = None, extraHeaders = None):
    """
    Deletes an existing virtual item store
    https://api.playfab.com/documentation/admin/method/DeleteStore
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeleteStore", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeleteTask(request, callback, customData = None, extraHeaders = None):
    """
    Delete a task.
    https://api.playfab.com/documentation/admin/method/DeleteTask
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeleteTask", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def DeleteTitle(request, callback, customData = None, extraHeaders = None):
    """
    Permanently deletes a title and all associated configuration
    https://api.playfab.com/documentation/admin/method/DeleteTitle
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/DeleteTitle", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ExportMasterPlayerData(request, callback, customData = None, extraHeaders = None):
    """
    Exports all associated data of a master player account
    https://api.playfab.com/documentation/admin/method/ExportMasterPlayerData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ExportMasterPlayerData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetActionsOnPlayersInSegmentTaskInstance(request, callback, customData = None, extraHeaders = None):
    """
    Get information about a ActionsOnPlayersInSegment task instance.
    https://api.playfab.com/documentation/admin/method/GetActionsOnPlayersInSegmentTaskInstance
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetActionsOnPlayersInSegmentTaskInstance", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetAllSegments(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves an array of player segment definitions. Results from this can be used in subsequent API calls such as
    GetPlayersInSegment which requires a Segment ID. While segment names can change the ID for that segment will not change.
    https://api.playfab.com/documentation/admin/method/GetAllSegments
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetAllSegments", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetCatalogItems(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the specified version of the title's catalog of virtual goods, including all defined properties
    https://api.playfab.com/documentation/admin/method/GetCatalogItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetCatalogItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetCloudScriptRevision(request, callback, customData = None, extraHeaders = None):
    """
    Gets the contents and information of a specific Cloud Script revision.
    https://api.playfab.com/documentation/admin/method/GetCloudScriptRevision
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetCloudScriptRevision", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetCloudScriptTaskInstance(request, callback, customData = None, extraHeaders = None):
    """
    Get detail information about a CloudScript task instance.
    https://api.playfab.com/documentation/admin/method/GetCloudScriptTaskInstance
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetCloudScriptTaskInstance", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetCloudScriptVersions(request, callback, customData = None, extraHeaders = None):
    """
    Lists all the current cloud script versions. For each version, information about the current published and latest
    revisions is also listed.
    https://api.playfab.com/documentation/admin/method/GetCloudScriptVersions
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetCloudScriptVersions", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetContentList(request, callback, customData = None, extraHeaders = None):
    """
    List all contents of the title and get statistics such as size
    https://api.playfab.com/documentation/admin/method/GetContentList
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetContentList", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetContentUploadUrl(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the pre-signed URL for uploading a content file. A subsequent HTTP PUT to the returned URL uploads the
    content. Also, please be aware that the Content service is specifically PlayFab's CDN offering, for which standard CDN
    rates apply.
    https://api.playfab.com/documentation/admin/method/GetContentUploadUrl
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetContentUploadUrl", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetDataReport(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves a download URL for the requested report
    https://api.playfab.com/documentation/admin/method/GetDataReport
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetDataReport", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetMatchmakerGameInfo(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the details for a specific completed session, including links to standard out and standard error logs
    https://api.playfab.com/documentation/admin/method/GetMatchmakerGameInfo
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetMatchmakerGameInfo", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetMatchmakerGameModes(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the details of defined game modes for the specified game server executable
    https://api.playfab.com/documentation/admin/method/GetMatchmakerGameModes
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetMatchmakerGameModes", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayedTitleList(request, callback, customData = None, extraHeaders = None):
    """
    Get the list of titles that the player has played
    https://api.playfab.com/documentation/admin/method/GetPlayedTitleList
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayedTitleList", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerIdFromAuthToken(request, callback, customData = None, extraHeaders = None):
    """
    Gets a player's ID from an auth token.
    https://api.playfab.com/documentation/admin/method/GetPlayerIdFromAuthToken
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerIdFromAuthToken", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerProfile(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the player's profile
    https://api.playfab.com/documentation/admin/method/GetPlayerProfile
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerProfile", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerSegments(request, callback, customData = None, extraHeaders = None):
    """
    List all segments that a player currently belongs to at this moment in time.
    https://api.playfab.com/documentation/admin/method/GetPlayerSegments
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerSegments", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerSharedSecrets(request, callback, customData = None, extraHeaders = None):
    """
    Returns all Player Shared Secret Keys including disabled and expired.
    https://api.playfab.com/documentation/admin/method/GetPlayerSharedSecrets
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerSharedSecrets", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayersInSegment(request, callback, customData = None, extraHeaders = None):
    """
    Allows for paging through all players in a given segment. This API creates a snapshot of all player profiles that match
    the segment definition at the time of its creation and lives through the Total Seconds to Live, refreshing its life span
    on each subsequent use of the Continuation Token. Profiles that change during the course of paging will not be reflected
    in the results. AB Test segments are currently not supported by this operation.
    https://api.playfab.com/documentation/admin/method/GetPlayersInSegment
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayersInSegment", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerStatisticDefinitions(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the configuration information for all player statistics defined in the title, regardless of whether they have
    a reset interval.
    https://api.playfab.com/documentation/admin/method/GetPlayerStatisticDefinitions
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerStatisticDefinitions", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerStatisticVersions(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the information on the available versions of the specified statistic.
    https://api.playfab.com/documentation/admin/method/GetPlayerStatisticVersions
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerStatisticVersions", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPlayerTags(request, callback, customData = None, extraHeaders = None):
    """
    Get all tags with a given Namespace (optional) from a player profile.
    https://api.playfab.com/documentation/admin/method/GetPlayerTags
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPlayerTags", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPolicy(request, callback, customData = None, extraHeaders = None):
    """
    Gets the requested policy.
    https://api.playfab.com/documentation/admin/method/GetPolicy
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPolicy", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetPublisherData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the key-value store of custom publisher settings
    https://api.playfab.com/documentation/admin/method/GetPublisherData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetPublisherData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetRandomResultTables(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the random drop table configuration for the title
    https://api.playfab.com/documentation/admin/method/GetRandomResultTables
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetRandomResultTables", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetServerBuildInfo(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the build details for the specified game server executable
    https://api.playfab.com/documentation/admin/method/GetServerBuildInfo
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetServerBuildInfo", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetServerBuildUploadUrl(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the pre-authorized URL for uploading a game server package containing a build (does not enable the build for
    use - see AddServerBuild)
    https://api.playfab.com/documentation/admin/method/GetServerBuildUploadUrl
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetServerBuildUploadUrl", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetStoreItems(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the set of items defined for the specified store, including all prices defined
    https://api.playfab.com/documentation/admin/method/GetStoreItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetStoreItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetTaskInstances(request, callback, customData = None, extraHeaders = None):
    """
    Query for task instances by task, status, or time range.
    https://api.playfab.com/documentation/admin/method/GetTaskInstances
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetTaskInstances", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetTasks(request, callback, customData = None, extraHeaders = None):
    """
    Get definition information on a specified task or all tasks within a title.
    https://api.playfab.com/documentation/admin/method/GetTasks
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetTasks", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetTitleData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the key-value store of custom title settings which can be read by the client
    https://api.playfab.com/documentation/admin/method/GetTitleData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetTitleData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetTitleInternalData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the key-value store of custom title settings which cannot be read by the client
    https://api.playfab.com/documentation/admin/method/GetTitleInternalData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetTitleInternalData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserAccountInfo(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the relevant details for a specified user, based upon a match against a supplied unique identifier
    https://api.playfab.com/documentation/admin/method/GetUserAccountInfo
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserAccountInfo", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserBans(request, callback, customData = None, extraHeaders = None):
    """
    Gets all bans for a user.
    https://api.playfab.com/documentation/admin/method/GetUserBans
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserBans", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the title-specific custom data for the user which is readable and writable by the client
    https://api.playfab.com/documentation/admin/method/GetUserData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserInternalData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the title-specific custom data for the user which cannot be accessed by the client
    https://api.playfab.com/documentation/admin/method/GetUserInternalData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserInternalData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserInventory(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the specified user's current inventory of virtual goods
    https://api.playfab.com/documentation/admin/method/GetUserInventory
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserInventory", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserPublisherData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the publisher-specific custom data for the user which is readable and writable by the client
    https://api.playfab.com/documentation/admin/method/GetUserPublisherData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserPublisherData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserPublisherInternalData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the publisher-specific custom data for the user which cannot be accessed by the client
    https://api.playfab.com/documentation/admin/method/GetUserPublisherInternalData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserPublisherInternalData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserPublisherReadOnlyData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the publisher-specific custom data for the user which can only be read by the client
    https://api.playfab.com/documentation/admin/method/GetUserPublisherReadOnlyData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserPublisherReadOnlyData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GetUserReadOnlyData(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the title-specific custom data for the user which can only be read by the client
    https://api.playfab.com/documentation/admin/method/GetUserReadOnlyData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GetUserReadOnlyData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def GrantItemsToUsers(request, callback, customData = None, extraHeaders = None):
    """
    Adds the specified items to the specified user inventories
    https://api.playfab.com/documentation/admin/method/GrantItemsToUsers
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/GrantItemsToUsers", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def IncrementLimitedEditionItemAvailability(request, callback, customData = None, extraHeaders = None):
    """
    Increases the global count for the given scarce resource.
    https://api.playfab.com/documentation/admin/method/IncrementLimitedEditionItemAvailability
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/IncrementLimitedEditionItemAvailability", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def IncrementPlayerStatisticVersion(request, callback, customData = None, extraHeaders = None):
    """
    Resets the indicated statistic, removing all player entries for it and backing up the old values.
    https://api.playfab.com/documentation/admin/method/IncrementPlayerStatisticVersion
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/IncrementPlayerStatisticVersion", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ListServerBuilds(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the build details for all game server executables which are currently defined for the title
    https://api.playfab.com/documentation/admin/method/ListServerBuilds
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ListServerBuilds", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ListVirtualCurrencyTypes(request, callback, customData = None, extraHeaders = None):
    """
    Retuns the list of all defined virtual currencies for the title
    https://api.playfab.com/documentation/admin/method/ListVirtualCurrencyTypes
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ListVirtualCurrencyTypes", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ModifyMatchmakerGameModes(request, callback, customData = None, extraHeaders = None):
    """
    Updates the game server mode details for the specified game server executable
    https://api.playfab.com/documentation/admin/method/ModifyMatchmakerGameModes
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ModifyMatchmakerGameModes", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ModifyServerBuild(request, callback, customData = None, extraHeaders = None):
    """
    Updates the build details for the specified game server executable
    https://api.playfab.com/documentation/admin/method/ModifyServerBuild
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ModifyServerBuild", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RefundPurchase(request, callback, customData = None, extraHeaders = None):
    """
    Attempts to process an order refund through the original real money payment provider.
    https://api.playfab.com/documentation/admin/method/RefundPurchase
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RefundPurchase", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RemovePlayerTag(request, callback, customData = None, extraHeaders = None):
    """
    Remove a given tag from a player profile. The tag's namespace is automatically generated based on the source of the tag.
    https://api.playfab.com/documentation/admin/method/RemovePlayerTag
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RemovePlayerTag", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RemoveServerBuild(request, callback, customData = None, extraHeaders = None):
    """
    Removes the game server executable specified from the set of those a client is permitted to request in a call to
    StartGame
    https://api.playfab.com/documentation/admin/method/RemoveServerBuild
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RemoveServerBuild", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RemoveVirtualCurrencyTypes(request, callback, customData = None, extraHeaders = None):
    """
    Removes one or more virtual currencies from the set defined for the title.
    https://api.playfab.com/documentation/admin/method/RemoveVirtualCurrencyTypes
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RemoveVirtualCurrencyTypes", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ResetCharacterStatistics(request, callback, customData = None, extraHeaders = None):
    """
    Completely removes all statistics for the specified character, for the current game
    https://api.playfab.com/documentation/admin/method/ResetCharacterStatistics
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ResetCharacterStatistics", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ResetPassword(request, callback, customData = None, extraHeaders = None):
    """
    Reset a player's password for a given title.
    https://api.playfab.com/documentation/admin/method/ResetPassword
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ResetPassword", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ResetUserStatistics(request, callback, customData = None, extraHeaders = None):
    """
    Completely removes all statistics for the specified user, for the current game
    https://api.playfab.com/documentation/admin/method/ResetUserStatistics
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ResetUserStatistics", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def ResolvePurchaseDispute(request, callback, customData = None, extraHeaders = None):
    """
    Attempts to resolve a dispute with the original order's payment provider.
    https://api.playfab.com/documentation/admin/method/ResolvePurchaseDispute
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/ResolvePurchaseDispute", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RevokeAllBansForUser(request, callback, customData = None, extraHeaders = None):
    """
    Revoke all active bans for a user.
    https://api.playfab.com/documentation/admin/method/RevokeAllBansForUser
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RevokeAllBansForUser", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RevokeBans(request, callback, customData = None, extraHeaders = None):
    """
    Revoke all active bans specified with BanId.
    https://api.playfab.com/documentation/admin/method/RevokeBans
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RevokeBans", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RevokeInventoryItem(request, callback, customData = None, extraHeaders = None):
    """
    Revokes access to an item in a user's inventory
    https://api.playfab.com/documentation/admin/method/RevokeInventoryItem
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RevokeInventoryItem", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RevokeInventoryItems(request, callback, customData = None, extraHeaders = None):
    """
    Revokes access for up to 25 items across multiple users and characters.
    https://api.playfab.com/documentation/admin/method/RevokeInventoryItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RevokeInventoryItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def RunTask(request, callback, customData = None, extraHeaders = None):
    """
    Run a task immediately regardless of its schedule.
    https://api.playfab.com/documentation/admin/method/RunTask
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/RunTask", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SendAccountRecoveryEmail(request, callback, customData = None, extraHeaders = None):
    """
    Forces an email to be sent to the registered email address for the user's account, with a link allowing the user to
    change the password.If an account recovery email template ID is provided, an email using the custom email template will
    be used.
    https://api.playfab.com/documentation/admin/method/SendAccountRecoveryEmail
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SendAccountRecoveryEmail", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetCatalogItems(request, callback, customData = None, extraHeaders = None):
    """
    Creates the catalog configuration of all virtual goods for the specified catalog version
    https://api.playfab.com/documentation/admin/method/SetCatalogItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetCatalogItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetPlayerSecret(request, callback, customData = None, extraHeaders = None):
    """
    Sets or resets the player's secret. Player secrets are used to sign API requests.
    https://api.playfab.com/documentation/admin/method/SetPlayerSecret
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetPlayerSecret", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetPublishedRevision(request, callback, customData = None, extraHeaders = None):
    """
    Sets the currently published revision of a title Cloud Script
    https://api.playfab.com/documentation/admin/method/SetPublishedRevision
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetPublishedRevision", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetPublisherData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the key-value store of custom publisher settings
    https://api.playfab.com/documentation/admin/method/SetPublisherData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetPublisherData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetStoreItems(request, callback, customData = None, extraHeaders = None):
    """
    Sets all the items in one virtual store
    https://api.playfab.com/documentation/admin/method/SetStoreItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetStoreItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetTitleData(request, callback, customData = None, extraHeaders = None):
    """
    Creates and updates the key-value store of custom title settings which can be read by the client
    https://api.playfab.com/documentation/admin/method/SetTitleData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetTitleData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetTitleInternalData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the key-value store of custom title settings which cannot be read by the client
    https://api.playfab.com/documentation/admin/method/SetTitleInternalData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetTitleInternalData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SetupPushNotification(request, callback, customData = None, extraHeaders = None):
    """
    Sets the Amazon Resource Name (ARN) for iOS and Android push notifications. Documentation on the exact restrictions can
    be found at: http://docs.aws.amazon.com/sns/latest/api/API_CreatePlatformApplication.html. Currently, Amazon device
    Messaging is not supported.
    https://api.playfab.com/documentation/admin/method/SetupPushNotification
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SetupPushNotification", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def SubtractUserVirtualCurrency(request, callback, customData = None, extraHeaders = None):
    """
    Decrements the specified virtual currency by the stated amount
    https://api.playfab.com/documentation/admin/method/SubtractUserVirtualCurrency
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/SubtractUserVirtualCurrency", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateBans(request, callback, customData = None, extraHeaders = None):
    """
    Updates information of a list of existing bans specified with Ban Ids.
    https://api.playfab.com/documentation/admin/method/UpdateBans
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateBans", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateCatalogItems(request, callback, customData = None, extraHeaders = None):
    """
    Updates the catalog configuration for virtual goods in the specified catalog version
    https://api.playfab.com/documentation/admin/method/UpdateCatalogItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateCatalogItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateCloudScript(request, callback, customData = None, extraHeaders = None):
    """
    Creates a new Cloud Script revision and uploads source code to it. Note that at this time, only one file should be
    submitted in the revision.
    https://api.playfab.com/documentation/admin/method/UpdateCloudScript
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateCloudScript", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdatePlayerSharedSecret(request, callback, customData = None, extraHeaders = None):
    """
    Updates a existing Player Shared Secret Key. It may take up to 5 minutes for this update to become generally available
    after this API returns.
    https://api.playfab.com/documentation/admin/method/UpdatePlayerSharedSecret
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdatePlayerSharedSecret", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdatePlayerStatisticDefinition(request, callback, customData = None, extraHeaders = None):
    """
    Updates a player statistic configuration for the title, optionally allowing the developer to specify a reset interval.
    https://api.playfab.com/documentation/admin/method/UpdatePlayerStatisticDefinition
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdatePlayerStatisticDefinition", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdatePolicy(request, callback, customData = None, extraHeaders = None):
    """
    Changes a policy for a title
    https://api.playfab.com/documentation/admin/method/UpdatePolicy
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdatePolicy", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateRandomResultTables(request, callback, customData = None, extraHeaders = None):
    """
    Updates the random drop table configuration for the title
    https://api.playfab.com/documentation/admin/method/UpdateRandomResultTables
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateRandomResultTables", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateStoreItems(request, callback, customData = None, extraHeaders = None):
    """
    Updates an existing virtual item store with new or modified items
    https://api.playfab.com/documentation/admin/method/UpdateStoreItems
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateStoreItems", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateTask(request, callback, customData = None, extraHeaders = None):
    """
    Update an existing task.
    https://api.playfab.com/documentation/admin/method/UpdateTask
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateTask", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the title-specific custom data for the user which is readable and writable by the client
    https://api.playfab.com/documentation/admin/method/UpdateUserData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserInternalData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the title-specific custom data for the user which cannot be accessed by the client
    https://api.playfab.com/documentation/admin/method/UpdateUserInternalData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserInternalData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserPublisherData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the publisher-specific custom data for the user which is readable and writable by the client
    https://api.playfab.com/documentation/admin/method/UpdateUserPublisherData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserPublisherData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserPublisherInternalData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the publisher-specific custom data for the user which cannot be accessed by the client
    https://api.playfab.com/documentation/admin/method/UpdateUserPublisherInternalData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserPublisherInternalData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserPublisherReadOnlyData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the publisher-specific custom data for the user which can only be read by the client
    https://api.playfab.com/documentation/admin/method/UpdateUserPublisherReadOnlyData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserPublisherReadOnlyData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserReadOnlyData(request, callback, customData = None, extraHeaders = None):
    """
    Updates the title-specific custom data for the user which can only be read by the client
    https://api.playfab.com/documentation/admin/method/UpdateUserReadOnlyData
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserReadOnlyData", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)

def UpdateUserTitleDisplayName(request, callback, customData = None, extraHeaders = None):
    """
    Updates the title specific display name for a user
    https://api.playfab.com/documentation/admin/method/UpdateUserTitleDisplayName
    """
    if not PlayFabSettings.DeveloperSecretKey:
        raise PlayFabErrors.PlayFabException("Must have DeveloperSecretKey set to call this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Admin/UpdateUserTitleDisplayName", request, "X-SecretKey", PlayFabSettings.DeveloperSecretKey, wrappedCallback, customData, extraHeaders)





import playfab.PlayFabErrors as PlayFabErrors
import playfab.PlayFabHTTP as PlayFabHTTP
import playfab.PlayFabSettings as PlayFabSettings

"""
All PlayFab entities have profiles, which hold top-level properties about the entity. These APIs give you the tools
needed to manage entity profiles.
"""

def GetGlobalPolicy(request, callback, customData = None, extraHeaders = None):
    """
    Gets the global title access policy
    https://api.playfab.com/documentation/profiles/method/GetGlobalPolicy
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Profile/GetGlobalPolicy", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def GetProfile(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the entity's profile.
    https://api.playfab.com/documentation/profiles/method/GetProfile
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Profile/GetProfile", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def GetProfiles(request, callback, customData = None, extraHeaders = None):
    """
    Retrieves the entity's profile.
    https://api.playfab.com/documentation/profiles/method/GetProfiles
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Profile/GetProfiles", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def SetGlobalPolicy(request, callback, customData = None, extraHeaders = None):
    """
    Sets the global title access policy
    https://api.playfab.com/documentation/profiles/method/SetGlobalPolicy
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Profile/SetGlobalPolicy", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def SetProfileLanguage(request, callback, customData = None, extraHeaders = None):
    """
    Updates the entity's language
    https://api.playfab.com/documentation/profiles/method/SetProfileLanguage
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Profile/SetProfileLanguage", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def SetProfilePolicy(request, callback, customData = None, extraHeaders = None):
    """
    Sets the profiles access policy
    https://api.playfab.com/documentation/profiles/method/SetProfilePolicy
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Profile/SetProfilePolicy", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)





import playfab.PlayFabErrors as PlayFabErrors
import playfab.PlayFabHTTP as PlayFabHTTP
import playfab.PlayFabSettings as PlayFabSettings

"""
Write custom PlayStream events for any PlayFab entity. PlayStream events can be used for analytics, reporting,
debugging, or to trigger custom actions in near real-time.
"""

def WriteEvents(request, callback, customData = None, extraHeaders = None):
    """
    Write batches of entity based events to PlayStream.
    https://api.playfab.com/documentation/events/method/WriteEvents
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Event/WriteEvents", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)





import playfab.PlayFabErrors as PlayFabErrors
import playfab.PlayFabHTTP as PlayFabHTTP
import playfab.PlayFabSettings as PlayFabSettings

"""
The Authentication APIs provide a convenient way to convert classic authentication responses into entity authentication
models. These APIs will provide you with the entity authentication token needed for subsequent Entity API calls.
"""

def GetEntityToken(request, callback, customData = None, extraHeaders = None):
    """
    Method to exchange a legacy AuthenticationTicket or title SecretKey for an Entity Token or to refresh a still valid
    Entity Token.
    https://api.playfab.com/documentation/authentication/method/GetEntityToken
    """
    authKey = None
    authValue = None
    if PlayFabSettings._internalSettings.EntityToken:
        authKey = "X-EntityToken"
        authValue = PlayFabSettings._internalSettings.EntityToken
    elif PlayFabSettings._internalSettings.ClientSessionTicket:
        authKey = "X-Authorization"
        authValue = PlayFabSettings._internalSettings.ClientSessionTicket 
    elif PlayFabSettings.DeveloperSecretKey:
        authKey = "X-SecretKey"
        authValue = PlayFabSettings.DeveloperSecretKey 

    def wrappedCallback(playFabResult, error):
        if playFabResult:
            PlayFabSettings._internalSettings.EntityToken = playFabResult["EntityToken"] if "EntityToken" in playFabResult else PlayFabSettings._internalSettings.EntityToken
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Authentication/GetEntityToken", request, authKey, authValue, wrappedCallback, customData, extraHeaders)





"""
These test API calls are synchronous and will block the current running python process.
"""

from playfab import *
import PlayFabManualTestSettings

# This needs to be set for the application to work properly.
# This can be found in the GameManger for your Title of the PlayFab website
PlayFabSettings.TitleId = PlayFabManualTestSettings.TitleId
customId = PlayFabManualTestSettings.customId

request = {}

request["CreateAccount"] = True
request["CustomId"] = customId
request["TitleId"] = PlayFabSettings.TitleId
request["LoginTitlePlayerAccountEntity"] = True

def loginCallback(success, fail):
    if fail:
        print(fail)
    else:
        print(success)

PlayFabClientAPI.LoginWithCustomID(request, loginCallback)

def entityTokenCallback(success, fail):
    global EntityKey
    if fail:
        print(fail)
    else:
        EntityKey = success["Entity"]
        print(success)

etRequest = {}
PlayFabAuthenticationAPI.GetEntityToken(etRequest, entityTokenCallback)

def entityObjectCallback(success, fail):
    if fail:
        print(fail)
    else:
        print(success)

# need to add entity id to this request
eoRequest = {}
PlayFabDataAPI.GetObjects(etRequest, entityObjectCallback)

eoRequest2 = {
    "Entity" : EntityKey
}
PlayFabDataAPI.GetObjects(eoRequest2, entityObjectCallback)

def titleDataReqCallback(success, fail):
    if fail:
        print(fail)
    else:
        print(success)

try:
    titleDataRequest = {}
    PlayFabServerAPI.GetTitleData(titleDataRequest, titleDataReqCallback)
except PlayFabErrors.PlayFabException as e:
    print("Caught expected error")
    PlayFabSettings.GlobalExceptionLogger(e)

PlayFabSettings.DeveloperSecretKey = PlayFabManualTestSettings.DeveloperSeceretKey

titleDataRequest2 = {}
PlayFabServerAPI.GetTitleData(titleDataRequest, titleDataReqCallback)



import playfab.PlayFabErrors as PlayFabErrors
import playfab.PlayFabHTTP as PlayFabHTTP
import playfab.PlayFabSettings as PlayFabSettings

"""
The Groups API is designed for any permanent or semi-permanent collections of Entities (players, or non-players). If you
want to make Guilds/Clans/Corporations/etc., then you should use groups. Groups can also be used to make chatrooms,
parties, or any other persistent collection of entities.
"""

def AcceptGroupApplication(request, callback, customData = None, extraHeaders = None):
    """
    Accepts an outstanding invitation to to join a group
    https://api.playfab.com/documentation/groups/method/AcceptGroupApplication
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/AcceptGroupApplication", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def AcceptGroupInvitation(request, callback, customData = None, extraHeaders = None):
    """
    Accepts an invitation to join a group
    https://api.playfab.com/documentation/groups/method/AcceptGroupInvitation
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/AcceptGroupInvitation", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def AddMembers(request, callback, customData = None, extraHeaders = None):
    """
    Adds members to a group or role.
    https://api.playfab.com/documentation/groups/method/AddMembers
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/AddMembers", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ApplyToGroup(request, callback, customData = None, extraHeaders = None):
    """
    Applies to join a group
    https://api.playfab.com/documentation/groups/method/ApplyToGroup
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ApplyToGroup", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def BlockEntity(request, callback, customData = None, extraHeaders = None):
    """
    Blocks a list of entities from joining a group.
    https://api.playfab.com/documentation/groups/method/BlockEntity
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/BlockEntity", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ChangeMemberRole(request, callback, customData = None, extraHeaders = None):
    """
    Changes the role membership of a list of entities from one role to another.
    https://api.playfab.com/documentation/groups/method/ChangeMemberRole
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ChangeMemberRole", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def CreateGroup(request, callback, customData = None, extraHeaders = None):
    """
    Creates a new group.
    https://api.playfab.com/documentation/groups/method/CreateGroup
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/CreateGroup", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def CreateRole(request, callback, customData = None, extraHeaders = None):
    """
    Creates a new group role.
    https://api.playfab.com/documentation/groups/method/CreateRole
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/CreateRole", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def DeleteGroup(request, callback, customData = None, extraHeaders = None):
    """
    Deletes a group and all roles, invitations, join requests, and blocks associated with it.
    https://api.playfab.com/documentation/groups/method/DeleteGroup
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/DeleteGroup", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def DeleteRole(request, callback, customData = None, extraHeaders = None):
    """
    Deletes an existing role in a group.
    https://api.playfab.com/documentation/groups/method/DeleteRole
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/DeleteRole", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def GetGroup(request, callback, customData = None, extraHeaders = None):
    """
    Gets information about a group and its roles
    https://api.playfab.com/documentation/groups/method/GetGroup
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/GetGroup", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def InviteToGroup(request, callback, customData = None, extraHeaders = None):
    """
    Invites a player to join a group
    https://api.playfab.com/documentation/groups/method/InviteToGroup
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/InviteToGroup", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def IsMember(request, callback, customData = None, extraHeaders = None):
    """
    Checks to see if an entity is a member of a group or role within the group
    https://api.playfab.com/documentation/groups/method/IsMember
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/IsMember", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ListGroupApplications(request, callback, customData = None, extraHeaders = None):
    """
    Lists all outstanding requests to join a group
    https://api.playfab.com/documentation/groups/method/ListGroupApplications
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ListGroupApplications", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ListGroupBlocks(request, callback, customData = None, extraHeaders = None):
    """
    Lists all entities blocked from joining a group
    https://api.playfab.com/documentation/groups/method/ListGroupBlocks
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ListGroupBlocks", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ListGroupInvitations(request, callback, customData = None, extraHeaders = None):
    """
    Lists all outstanding invitations for a group
    https://api.playfab.com/documentation/groups/method/ListGroupInvitations
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ListGroupInvitations", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ListGroupMembers(request, callback, customData = None, extraHeaders = None):
    """
    Lists all members for a group
    https://api.playfab.com/documentation/groups/method/ListGroupMembers
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ListGroupMembers", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ListMembership(request, callback, customData = None, extraHeaders = None):
    """
    Lists all groups and roles for an entity
    https://api.playfab.com/documentation/groups/method/ListMembership
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ListMembership", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def ListMembershipOpportunities(request, callback, customData = None, extraHeaders = None):
    """
    Lists all outstanding invitations and group applications for an entity
    https://api.playfab.com/documentation/groups/method/ListMembershipOpportunities
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/ListMembershipOpportunities", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def RemoveGroupApplication(request, callback, customData = None, extraHeaders = None):
    """
    Removes an application to join a group
    https://api.playfab.com/documentation/groups/method/RemoveGroupApplication
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/RemoveGroupApplication", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def RemoveGroupInvitation(request, callback, customData = None, extraHeaders = None):
    """
    Removes an invitation join a group
    https://api.playfab.com/documentation/groups/method/RemoveGroupInvitation
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/RemoveGroupInvitation", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def RemoveMembers(request, callback, customData = None, extraHeaders = None):
    """
    Removes members from a group.
    https://api.playfab.com/documentation/groups/method/RemoveMembers
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/RemoveMembers", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def UnblockEntity(request, callback, customData = None, extraHeaders = None):
    """
    Unblocks a list of entities from joining a group
    https://api.playfab.com/documentation/groups/method/UnblockEntity
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/UnblockEntity", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def UpdateGroup(request, callback, customData = None, extraHeaders = None):
    """
    Updates non-membership data about a group.
    https://api.playfab.com/documentation/groups/method/UpdateGroup
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/UpdateGroup", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)

def UpdateRole(request, callback, customData = None, extraHeaders = None):
    """
    Updates metadata about a role.
    https://api.playfab.com/documentation/groups/method/UpdateRole
    """
    if not PlayFabSettings._internalSettings.EntityToken:
        raise PlayFabErrors.PlayFabException("Must call GetEntityToken before calling this method")

    def wrappedCallback(playFabResult, error):
        if callback:
            callback(playFabResult, error)

    PlayFabHTTP.DoPost("/Group/UpdateRole", request, "X-EntityToken", PlayFabSettings._internalSettings.EntityToken, wrappedCallback, customData, extraHeaders)





from enum import Enum
class PlayFabErrorCode(Enum):
    """
    Error codes returned by PlayFabAPIs
    """
    Success = 0,
    Unknown = 1,
    ConnectionError = 2,
    JsonParseError = 3,
    UnkownError = 500,
    InvalidParams = 1000,
    AccountNotFound = 1001,
    AccountBanned = 1002,
    InvalidUsernameOrPassword = 1003,
    InvalidTitleId = 1004,
    InvalidEmailAddress = 1005,
    EmailAddressNotAvailable = 1006,
    InvalidUsername = 1007,
    InvalidPassword = 1008,
    UsernameNotAvailable = 1009,
    InvalidSteamTicket = 1010,
    AccountAlreadyLinked = 1011,
    LinkedAccountAlreadyClaimed = 1012,
    InvalidFacebookToken = 1013,
    AccountNotLinked = 1014,
    FailedByPaymentProvider = 1015,
    CouponCodeNotFound = 1016,
    InvalidContainerItem = 1017,
    ContainerNotOwned = 1018,
    KeyNotOwned = 1019,
    InvalidItemIdInTable = 1020,
    InvalidReceipt = 1021,
    ReceiptAlreadyUsed = 1022,
    ReceiptCancelled = 1023,
    GameNotFound = 1024,
    GameModeNotFound = 1025,
    InvalidGoogleToken = 1026,
    UserIsNotPartOfDeveloper = 1027,
    InvalidTitleForDeveloper = 1028,
    TitleNameConflicts = 1029,
    UserisNotValid = 1030,
    ValueAlreadyExists = 1031,
    BuildNotFound = 1032,
    PlayerNotInGame = 1033,
    InvalidTicket = 1034,
    InvalidDeveloper = 1035,
    InvalidOrderInfo = 1036,
    RegistrationIncomplete = 1037,
    InvalidPlatform = 1038,
    UnknownError = 1039,
    SteamApplicationNotOwned = 1040,
    WrongSteamAccount = 1041,
    TitleNotActivated = 1042,
    RegistrationSessionNotFound = 1043,
    NoSuchMod = 1044,
    FileNotFound = 1045,
    DuplicateEmail = 1046,
    ItemNotFound = 1047,
    ItemNotOwned = 1048,
    ItemNotRecycleable = 1049,
    ItemNotAffordable = 1050,
    InvalidVirtualCurrency = 1051,
    WrongVirtualCurrency = 1052,
    WrongPrice = 1053,
    NonPositiveValue = 1054,
    InvalidRegion = 1055,
    RegionAtCapacity = 1056,
    ServerFailedToStart = 1057,
    NameNotAvailable = 1058,
    InsufficientFunds = 1059,
    InvalidDeviceID = 1060,
    InvalidPushNotificationToken = 1061,
    NoRemainingUses = 1062,
    InvalidPaymentProvider = 1063,
    PurchaseInitializationFailure = 1064,
    DuplicateUsername = 1065,
    InvalidBuyerInfo = 1066,
    NoGameModeParamsSet = 1067,
    BodyTooLarge = 1068,
    ReservedWordInBody = 1069,
    InvalidTypeInBody = 1070,
    InvalidRequest = 1071,
    ReservedEventName = 1072,
    InvalidUserStatistics = 1073,
    NotAuthenticated = 1074,
    StreamAlreadyExists = 1075,
    ErrorCreatingStream = 1076,
    StreamNotFound = 1077,
    InvalidAccount = 1078,
    PurchaseDoesNotExist = 1080,
    InvalidPurchaseTransactionStatus = 1081,
    APINotEnabledForGameClientAccess = 1082,
    NoPushNotificationARNForTitle = 1083,
    BuildAlreadyExists = 1084,
    BuildPackageDoesNotExist = 1085,
    CustomAnalyticsEventsNotEnabledForTitle = 1087,
    InvalidSharedGroupId = 1088,
    NotAuthorized = 1089,
    MissingTitleGoogleProperties = 1090,
    InvalidItemProperties = 1091,
    InvalidPSNAuthCode = 1092,
    InvalidItemId = 1093,
    PushNotEnabledForAccount = 1094,
    PushServiceError = 1095,
    ReceiptDoesNotContainInAppItems = 1096,
    ReceiptContainsMultipleInAppItems = 1097,
    InvalidBundleID = 1098,
    JavascriptException = 1099,
    InvalidSessionTicket = 1100,
    UnableToConnectToDatabase = 1101,
    InternalServerError = 1110,
    InvalidReportDate = 1111,
    ReportNotAvailable = 1112,
    DatabaseThroughputExceeded = 1113,
    InvalidGameTicket = 1115,
    ExpiredGameTicket = 1116,
    GameTicketDoesNotMatchLobby = 1117,
    LinkedDeviceAlreadyClaimed = 1118,
    DeviceAlreadyLinked = 1119,
    DeviceNotLinked = 1120,
    PartialFailure = 1121,
    PublisherNotSet = 1122,
    ServiceUnavailable = 1123,
    VersionNotFound = 1124,
    RevisionNotFound = 1125,
    InvalidPublisherId = 1126,
    DownstreamServiceUnavailable = 1127,
    APINotIncludedInTitleUsageTier = 1128,
    DAULimitExceeded = 1129,
    APIRequestLimitExceeded = 1130,
    InvalidAPIEndpoint = 1131,
    BuildNotAvailable = 1132,
    ConcurrentEditError = 1133,
    ContentNotFound = 1134,
    CharacterNotFound = 1135,
    CloudScriptNotFound = 1136,
    ContentQuotaExceeded = 1137,
    InvalidCharacterStatistics = 1138,
    PhotonNotEnabledForTitle = 1139,
    PhotonApplicationNotFound = 1140,
    PhotonApplicationNotAssociatedWithTitle = 1141,
    InvalidEmailOrPassword = 1142,
    FacebookAPIError = 1143,
    InvalidContentType = 1144,
    KeyLengthExceeded = 1145,
    DataLengthExceeded = 1146,
    TooManyKeys = 1147,
    FreeTierCannotHaveVirtualCurrency = 1148,
    MissingAmazonSharedKey = 1149,
    AmazonValidationError = 1150,
    InvalidPSNIssuerId = 1151,
    PSNInaccessible = 1152,
    ExpiredAuthToken = 1153,
    FailedToGetEntitlements = 1154,
    FailedToConsumeEntitlement = 1155,
    TradeAcceptingUserNotAllowed = 1156,
    TradeInventoryItemIsAssignedToCharacter = 1157,
    TradeInventoryItemIsBundle = 1158,
    TradeStatusNotValidForCancelling = 1159,
    TradeStatusNotValidForAccepting = 1160,
    TradeDoesNotExist = 1161,
    TradeCancelled = 1162,
    TradeAlreadyFilled = 1163,
    TradeWaitForStatusTimeout = 1164,
    TradeInventoryItemExpired = 1165,
    TradeMissingOfferedAndAcceptedItems = 1166,
    TradeAcceptedItemIsBundle = 1167,
    TradeAcceptedItemIsStackable = 1168,
    TradeInventoryItemInvalidStatus = 1169,
    TradeAcceptedCatalogItemInvalid = 1170,
    TradeAllowedUsersInvalid = 1171,
    TradeInventoryItemDoesNotExist = 1172,
    TradeInventoryItemIsConsumed = 1173,
    TradeInventoryItemIsStackable = 1174,
    TradeAcceptedItemsMismatch = 1175,
    InvalidKongregateToken = 1176,
    FeatureNotConfiguredForTitle = 1177,
    NoMatchingCatalogItemForReceipt = 1178,
    InvalidCurrencyCode = 1179,
    NoRealMoneyPriceForCatalogItem = 1180,
    TradeInventoryItemIsNotTradable = 1181,
    TradeAcceptedCatalogItemIsNotTradable = 1182,
    UsersAlreadyFriends = 1183,
    LinkedIdentifierAlreadyClaimed = 1184,
    CustomIdNotLinked = 1185,
    TotalDataSizeExceeded = 1186,
    DeleteKeyConflict = 1187,
    InvalidXboxLiveToken = 1188,
    ExpiredXboxLiveToken = 1189,
    ResettableStatisticVersionRequired = 1190,
    NotAuthorizedByTitle = 1191,
    NoPartnerEnabled = 1192,
    InvalidPartnerResponse = 1193,
    APINotEnabledForGameServerAccess = 1194,
    StatisticNotFound = 1195,
    StatisticNameConflict = 1196,
    StatisticVersionClosedForWrites = 1197,
    StatisticVersionInvalid = 1198,
    APIClientRequestRateLimitExceeded = 1199,
    InvalidJSONContent = 1200,
    InvalidDropTable = 1201,
    StatisticVersionAlreadyIncrementedForScheduledInterval = 1202,
    StatisticCountLimitExceeded = 1203,
    StatisticVersionIncrementRateExceeded = 1204,
    ContainerKeyInvalid = 1205,
    CloudScriptExecutionTimeLimitExceeded = 1206,
    NoWritePermissionsForEvent = 1207,
    CloudScriptFunctionArgumentSizeExceeded = 1208,
    CloudScriptAPIRequestCountExceeded = 1209,
    CloudScriptAPIRequestError = 1210,
    CloudScriptHTTPRequestError = 1211,
    InsufficientGuildRole = 1212,
    GuildNotFound = 1213,
    OverLimit = 1214,
    EventNotFound = 1215,
    InvalidEventField = 1216,
    InvalidEventName = 1217,
    CatalogNotConfigured = 1218,
    OperationNotSupportedForPlatform = 1219,
    SegmentNotFound = 1220,
    StoreNotFound = 1221,
    InvalidStatisticName = 1222,
    TitleNotQualifiedForLimit = 1223,
    InvalidServiceLimitLevel = 1224,
    ServiceLimitLevelInTransition = 1225,
    CouponAlreadyRedeemed = 1226,
    GameServerBuildSizeLimitExceeded = 1227,
    GameServerBuildCountLimitExceeded = 1228,
    VirtualCurrencyCountLimitExceeded = 1229,
    VirtualCurrencyCodeExists = 1230,
    TitleNewsItemCountLimitExceeded = 1231,
    InvalidTwitchToken = 1232,
    TwitchResponseError = 1233,
    ProfaneDisplayName = 1234,
    UserAlreadyAdded = 1235,
    InvalidVirtualCurrencyCode = 1236,
    VirtualCurrencyCannotBeDeleted = 1237,
    IdentifierAlreadyClaimed = 1238,
    IdentifierNotLinked = 1239,
    InvalidContinuationToken = 1240,
    ExpiredContinuationToken = 1241,
    InvalidSegment = 1242,
    InvalidSessionId = 1243,
    SessionLogNotFound = 1244,
    InvalidSearchTerm = 1245,
    TwoFactorAuthenticationTokenRequired = 1246,
    GameServerHostCountLimitExceeded = 1247,
    PlayerTagCountLimitExceeded = 1248,
    RequestAlreadyRunning = 1249,
    ActionGroupNotFound = 1250,
    MaximumSegmentBulkActionJobsRunning = 1251,
    NoActionsOnPlayersInSegmentJob = 1252,
    DuplicateStatisticName = 1253,
    ScheduledTaskNameConflict = 1254,
    ScheduledTaskCreateConflict = 1255,
    InvalidScheduledTaskName = 1256,
    InvalidTaskSchedule = 1257,
    SteamNotEnabledForTitle = 1258,
    LimitNotAnUpgradeOption = 1259,
    NoSecretKeyEnabledForCloudScript = 1260,
    TaskNotFound = 1261,
    TaskInstanceNotFound = 1262,
    InvalidIdentityProviderId = 1263,
    MisconfiguredIdentityProvider = 1264,
    InvalidScheduledTaskType = 1265,
    BillingInformationRequired = 1266,
    LimitedEditionItemUnavailable = 1267,
    InvalidAdPlacementAndReward = 1268,
    AllAdPlacementViewsAlreadyConsumed = 1269,
    GoogleOAuthNotConfiguredForTitle = 1270,
    GoogleOAuthError = 1271,
    UserNotFriend = 1272,
    InvalidSignature = 1273,
    InvalidPublicKey = 1274,
    GoogleOAuthNoIdTokenIncludedInResponse = 1275,
    StatisticUpdateInProgress = 1276,
    LeaderboardVersionNotAvailable = 1277,
    StatisticAlreadyHasPrizeTable = 1279,
    PrizeTableHasOverlappingRanks = 1280,
    PrizeTableHasMissingRanks = 1281,
    PrizeTableRankStartsAtZero = 1282,
    InvalidStatistic = 1283,
    ExpressionParseFailure = 1284,
    ExpressionInvokeFailure = 1285,
    ExpressionTooLong = 1286,
    DataUpdateRateExceeded = 1287,
    RestrictedEmailDomain = 1288,
    EncryptionKeyDisabled = 1289,
    EncryptionKeyMissing = 1290,
    EncryptionKeyBroken = 1291,
    NoSharedSecretKeyConfigured = 1292,
    SecretKeyNotFound = 1293,
    PlayerSecretAlreadyConfigured = 1294,
    APIRequestsDisabledForTitle = 1295,
    InvalidSharedSecretKey = 1296,
    PrizeTableHasNoRanks = 1297,
    ProfileDoesNotExist = 1298,
    ContentS3OriginBucketNotConfigured = 1299,
    InvalidEnvironmentForReceipt = 1300,
    EncryptedRequestNotAllowed = 1301,
    SignedRequestNotAllowed = 1302,
    RequestViewConstraintParamsNotAllowed = 1303,
    BadPartnerConfiguration = 1304,
    XboxBPCertificateFailure = 1305,
    XboxXASSExchangeFailure = 1306,
    InvalidEntityId = 1307,
    StatisticValueAggregationOverflow = 1308,
    EmailMessageFromAddressIsMissing = 1309,
    EmailMessageToAddressIsMissing = 1310,
    SmtpServerAuthenticationError = 1311,
    SmtpServerLimitExceeded = 1312,
    SmtpServerInsufficientStorage = 1313,
    SmtpServerCommunicationError = 1314,
    SmtpServerGeneralFailure = 1315,
    EmailClientTimeout = 1316,
    EmailClientCanceledTask = 1317,
    EmailTemplateMissing = 1318,
    InvalidHostForTitleId = 1319,
    EmailConfirmationTokenDoesNotExist = 1320,
    EmailConfirmationTokenExpired = 1321,
    AccountDeleted = 1322,
    PlayerSecretNotConfigured = 1323,
    InvalidSignatureTime = 1324,
    NoContactEmailAddressFound = 1325,
    InvalidAuthToken = 1326,
    AuthTokenDoesNotExist = 1327,
    AuthTokenExpired = 1328,
    AuthTokenAlreadyUsedToResetPassword = 1329,
    MembershipNameTooLong = 1330,
    MembershipNotFound = 1331,
    GoogleServiceAccountInvalid = 1332,
    GoogleServiceAccountParseFailure = 1333,
    EntityTokenMissing = 1334,
    EntityTokenInvalid = 1335,
    EntityTokenExpired = 1336,
    EntityTokenRevoked = 1337,
    InvalidProductForSubscription = 1338,
    XboxInaccessible = 1339,
    SubscriptionAlreadyTaken = 1340,
    SmtpAddonNotEnabled = 1341,
    APIConcurrentRequestLimitExceeded = 1342,
    XboxRejectedXSTSExchangeRequest = 1343,
    VariableNotDefined = 1344,
    TemplateVersionNotDefined = 1345,
    FileTooLarge = 1346,
    TitleDeleted = 1347,
    TitleContainsUserAccounts = 1348,
    TitleDeletionPlayerCleanupFailure = 1349,
    EntityFileOperationPending = 1350,
    NoEntityFileOperationPending = 1351,
    EntityProfileVersionMismatch = 1352,
    TemplateVersionTooOld = 1353,
    MembershipDefinitionInUse = 1354,
    PaymentPageNotConfigured = 1355,
    FailedLoginAttemptRateLimitExceeded = 1356,
    EntityBlockedByGroup = 1357,
    RoleDoesNotExist = 1358,
    EntityIsAlreadyMember = 1359,
    DuplicateRoleId = 1360,
    GroupInvitationNotFound = 1361,
    GroupApplicationNotFound = 1362,
    OutstandingInvitationAcceptedInstead = 1363,
    OutstandingApplicationAcceptedInstead = 1364,
    RoleIsGroupDefaultMember = 1365,
    RoleIsGroupAdmin = 1366,
    RoleNameNotAvailable = 1367,
    GroupNameNotAvailable = 1368,
    EmailReportAlreadySent = 1369,
    EmailReportRecipientBlacklisted = 1370,
    EventNamespaceNotAllowed = 1371,
    EventEntityNotAllowed = 1372,
    InvalidEntityType = 1373,
    NullTokenResultFromAad = 1374,
    InvalidTokenResultFromAad = 1375,
    NoValidCertificateForAad = 1376,
    InvalidCertificateForAad = 1377,
    DuplicateDropTableId = 1378,
    MultiplayerServerError = 1379,
    MultiplayerServerTooManyRequests = 1380,
    MultiplayerServerNoContent = 1381,
    MultiplayerServerBadRequest = 1382,
    MultiplayerServerUnauthorized = 1383,
    MultiplayerServerForbidden = 1384,
    MultiplayerServerNotFound = 1385,
    MultiplayerServerConflict = 1386,
    MultiplayerServerInternalServerError = 1387,
    MultiplayerServerUnavailable = 1388,
    ExplicitContentDetected = 1389,
    PIIContentDetected = 1390,
    InvalidScheduledTaskParameter = 1391,
    PerEntityEventRateLimitExceeded = 1392,
    TitleDefaultLanguageNotSet = 1393,
    EmailTemplateMissingDefaultVersion = 1394,
    FacebookInstantGamesIdNotLinked = 1395,
    InvalidFacebookInstantGamesSignature = 1396,
    FacebookInstantGamesAuthNotConfiguredForTitle = 1397,
    MatchmakingEntityInvalid = 2001,
    MatchmakingPlayerAttributesInvalid = 2002,
    MatchmakingCreateRequestMissing = 2003,
    MatchmakingCreateRequestCreatorMissing = 2004,
    MatchmakingCreateRequestCreatorIdMissing = 2005,
    MatchmakingCreateRequestUserListMissing = 2006,
    MatchmakingCreateRequestGiveUpAfterInvalid = 2007,
    MatchmakingTicketIdMissing = 2008,
    MatchmakingMatchIdMissing = 2009,
    MatchmakingMatchIdIdMissing = 2010,
    MatchmakingQueueNameMissing = 2011,
    MatchmakingTitleIdMissing = 2012,
    MatchmakingTicketIdIdMissing = 2013,
    MatchmakingPlayerIdMissing = 2014,
    MatchmakingJoinRequestUserMissing = 2015,
    MatchmakingQueueConfigNotFound = 2016,
    MatchmakingMatchNotFound = 2017,
    MatchmakingTicketNotFound = 2018,
    MatchmakingCreateTicketServerIdentityInvalid = 2019,
    MatchmakingCreateTicketClientIdentityInvalid = 2020,
    MatchmakingGetTicketUserMismatch = 2021,
    MatchmakingJoinTicketServerIdentityInvalid = 2022,
    MatchmakingJoinTicketUserIdentityMismatch = 2023,
    MatchmakingCancelTicketServerIdentityInvalid = 2024,
    MatchmakingCancelTicketUserIdentityMismatch = 2025,
    MatchmakingGetMatchIdentityMismatch = 2026,
    MatchmakingPlayerIdentityMismatch = 2027,
    MatchmakingAlreadyJoinedTicket = 2028,
    MatchmakingTicketAlreadyCompleted = 2029,
    MatchmakingQueueNameInvalid = 2030,
    MatchmakingQueueConfigInvalid = 2031,
    MatchmakingMemberProfileInvalid = 2032,
    WriteAttemptedDuringExport = 2033,
    NintendoSwitchDeviceIdNotLinked = 2034,
    MatchmakingNotEnabled = 2035

class PlayFabError:
    def __init__(self, *args):
        """
        The first args item is expected to be a valid dictionary
        """
        if len(args) == 1:
            self.fromJson(args[0])
        else:
            self.HttpCode = 408
            self.HttpStatus = "Request Timeout"
            self.Error = "ServiceUnavailable"
            self.ErrorCode = PlayFabErrorCode.ServiceUnavailable
            self.ErrorMessage = "Unable to contact PlayFab server"
            self.ErrorDetails = None # dictionary of string keys and list of strings for values

    def fromJson(self, other):
        self.HttpCode = other["code"]
        self.HttpStatus = other["status"]
        self.Error = other["error"]
        self.ErrorCode = other["errorCode"]
        self.ErrorMessage = other["errorMessage"]
        self.ErrorDetails = other.get("errorDetails", None)

    def GenerateErrorReport(self):
        str = ""
        if self.ErrorMessage != None:
            str = self.ErrorMessage
        if self.ErrorDetails == None:
            return str

        for i in self.ErrorDetails.items():
            str += "{}".format(i)

        return str

    def __str__(self):
        return self.GenerateErrorReport()

class PlayFabException(Exception):
    pass




import playfab.PlayFabAdminAPI as PlayFabAdminAPI
import playfab.PlayFabClientAPI as PlayFabClientAPI
import playfab.PlayFabMatchmakerAPI as PlayFabMatchmakerAPI
import playfab.PlayFabServerAPI as PlayFabServerAPI
import playfab.PlayFabAuthenticationAPI as PlayFabAuthenticationAPI
import playfab.PlayFabCloudScriptAPI as PlayFabCloudScriptAPI
import playfab.PlayFabDataAPI as PlayFabDataAPI
import playfab.PlayFabEventsAPI as PlayFabEventsAPI
import playfab.PlayFabGroupsAPI as PlayFabGroupsAPI
import playfab.PlayFabProfilesAPI as PlayFabProfilesAPI

import playfab.PlayFabErrors as PlayFabErrors
import playfab.PlayFabHTTP as PlayFabHTTP
import playfab.PlayFabSettings as PlayFabSettings

__all__ = ["PlayFabErrors", "PlayFabHTTP", "PlayFabSettings"]

__all__.append("PlayFabAdminAPI")
__all__.append("PlayFabClientAPI")
__all__.append("PlayFabMatchmakerAPI")
__all__.append("PlayFabServerAPI")
__all__.append("PlayFabAuthenticationAPI")
__all__.append("PlayFabCloudScriptAPI")
__all__.append("PlayFabDataAPI")
__all__.append("PlayFabEventsAPI")
__all__.append("PlayFabGroupsAPI")
__all__.append("PlayFabProfilesAPI")




import setuptools
with open("README.md", "r") as fh:
        long_description = fh.read()
        
setuptools.setup(
    name="playfab",
    version="0.0.180829",
    author="PlayFab Dev Tools team",
    author_email="devrel@playfab.com",
    description="PlayFab Python SDK current API version: 0.0.180829",
    long_description=long_description,
    url="https://github.com/PlayFab/PythonSdk",
    packages=setuptools.find_packages(),
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Topic :: Games/Entertainment",
    ),
)
